Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: src/date.js

Issue 7830036: Optimize isFinite and isNaN. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Made the change general by moving putting it in the NUMBER_IS_FINITE macro. Created 9 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ast.cc ('k') | src/extensions/externalize-string-extension.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/date.js
diff --git a/src/date.js b/src/date.js
index ccefce57638812366eb32776b5cbdc6c1d79ebaf..79b846d4a7060efc938990330cf8396b07224073 100644
--- a/src/date.js
+++ b/src/date.js
@@ -1048,19 +1048,18 @@ function ResetDateCache() {
// -------------------------------------------------------------------
-function SetUpDate() {
- %CheckIsBootstrapping();
- // Set up non-enumerable properties of the Date object itself.
+function SetupDate() {
+ // Setup non-enumerable properties of the Date object itself.
InstallFunctions($Date, DONT_ENUM, $Array(
"UTC", DateUTC,
"parse", DateParse,
"now", DateNow
));
// Set up non-enumerable constructor property of the Date prototype object.
%SetProperty($Date.prototype, "constructor", $Date, DONT_ENUM);
// Set up non-enumerable functions of the Date prototype object and
// set their names.
InstallFunctionsOnHiddenPrototype($Date.prototype, DONT_ENUM, $Array(
"toString", DateToString,
@@ -1112,4 +1111,4 @@ function SetUpDate() {
));
}
-SetUpDate();
+SetupDate();
« no previous file with comments | « src/ast.cc ('k') | src/extensions/externalize-string-extension.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -1048,19 +1048,18 @@ function ResetDateCache() {
"now", DateNow
));
- // Set up non-enumerable constructor property of the Date prototype object.
+ // Setup non-enumerable constructor property of the Date prototype object.
%SetProperty($Date.prototype, "constructor", $Date, DONT_ENUM);
@@ -1048,19 +1048,18 @@ function ResetDateCache() {
%SetProperty($Date.prototype, "constructor", $Date, DONT_ENUM);
- // Set up non-enumerable functions of the Date prototype object and
+ // Setup non-enumerable functions of the Date prototype object and
// set their names.
InstallFunctionsOnHiddenPrototype($Date.prototype, DONT_ENUM, $Array(
This is Rietveld 408576698